#!/bin/bash

source ./tasks/shims/install_backend
source ./tasks/shims/install_venv
source ./tasks/shims/activate_venv
source ./tasks/shims/sync_requirements
source ./tasks/shims/configure_project

echo Done!
